<?php
    /*
     * $Id: setup.php,v 1.4 2004/09/24 14:57:31 indiri69 Exp $
     */
    function squirrelmail_plugin_init_get_uuencode() {
        global $squirrelmail_plugin_hooks;

        $squirrelmail_plugin_hooks['message_body']['get_uuencode']     = 'get_uuencode_message_body';
        $squirrelmail_plugin_hooks['read_body_bottom']['get_uuencode'] = 'get_uuencode_read_body_bottom';
        $squirrelmail_plugin_hooks['decode_body']['get_uuencode']      = 'get_uuencode_decode_body';
    }

    function get_uuencode_message_body (&$data) {
        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
        get_uuencode_body($data);
    }

    function get_uuencode_read_body_bottom () {
        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
        get_uuencode_link();
    }

    function get_uuencode_decode_body ($encoding) {
        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
        return get_uuencode_check_encoding($encoding);
    }

    function get_uuencode_version () {
        return '3.1-1.4.x';
    }
?>
